@@ -1,29 +1,15 @@
-/* mpdscribble (MPD Client)
- * Copyright (C) 2008-2019 The Music Player Daemon Project
- * Project homepage: http://musicpd.org
-
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
-
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
-
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-*/
+// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright The Music Player Daemon Project
 
 #include "IniFile.hxx"
 #include "system/Error.hxx"
 #include "util/CharUtil.hxx"
 #include "util/RuntimeError.hxx"
 #include "util/ScopeExit.hxx"
+#include "util/StringSplit.hxx"
 #include "util/StringStrip.hxx"
-#include "util/StringView.hxx"
+
+#include <string_view>
 
 #include <stdio.h>
 
@@ -35,7 +21,7 @@ IsValidSectionNameChar(char ch) noexcept
 
 [[gnu::pure]]
 static bool
-IsValidSectionName(StringView name) noexcept
+IsValidSectionName(std::string_view name) noexcept
 {
 	if (name.empty())
 		return false;
@@ -55,7 +41,7 @@ IsValidKeyChar(char ch) noexcept
 
 [[gnu::pure]]
 static bool
-IsValidKey(StringView name) noexcept
+IsValidKey(std::string_view name) noexcept
 {
 	if (name.empty())
 		return false;
@@ -75,7 +61,7 @@ class IniParser {
 	IniFile::iterator section;
 
 public:
-	void ParseLine(char *line);
+	void ParseLine(std::string_view line);
 
 	auto Commit() noexcept {
 		return std::move(data);
@@ -83,51 +69,45 @@ public:
 };
 
 void
-IniParser::ParseLine(char *line)
+IniParser::ParseLine(std::string_view line)
 {
-	line = Strip(line);
-	if (*line == 0 || *line == '#')
+	line = StripLeft(line);
+	if (line.empty() || line.front() == '#')
 		/* ignore empty lines and comments */
 		return;
 
-	if (*line == '[') {
+	if (line.front() == '[') {
 		/* a new section */
 
-		line = StripLeft(line + 1);
-		char *end = strchr(line, ']');
-		if (end == nullptr)
+		line = StripLeft(line.substr(1));
+
+		auto [name, rest] = Split(line, ']');
+		if (rest.data() == nullptr)
 			throw std::runtime_error("Missing ']'");
 
-		StringView name(line, end);
-		name.StripRight();
-
+		name = Strip(name);
 		if (!IsValidSectionName(name))
 			throw std::runtime_error("Invalid section name");
 
-		line = end + 1;
-		if (*line != 0)
+		if (!StripLeft(rest).empty())
 			throw std::runtime_error("Garbage after section");
 
-		auto i = data.emplace(std::string(name.data, name.size),
-				      IniSection());
+		auto i = data.emplace(name, IniSection{});
 		if (!i.second)
 			throw FormatRuntimeError("Duplicate section name: %.*s",
-						 int(name.size), name.data);
+						 int(name.size()), name.data());
 
 		section = i.first;
-	} else if (IsValidKeyChar(*line)) {
-		char *eq = strchr(line, '=');
-		if (eq == nullptr)
+	} else if (IsValidKeyChar(line.front())) {
+		auto [key, value] = Split(line, '=');
+		if (value.data() == nullptr)
 			throw std::runtime_error("Missing '='");
 
-		StringView key(line, eq);
-		key.StripRight();
-
+		key = StripRight(key);
 		if (!IsValidKey(key))
 			throw std::runtime_error("Invalid key");
 
-		StringView value(eq + 1);
-		value.StripLeft();
+		value = Strip(value);
 
 		// TODO: support quoted values
 
@@ -135,11 +115,10 @@ IniParser::ParseLine(char *line)
 			section = data.emplace(std::string(),
 					       IniSection()).first;
 
-		auto i = section->second.emplace(std::string(key.data, key.size),
-						 std::string(value.data, value.size));
+		auto i = section->second.emplace(key, value);
 		if (!i.second)
 			throw FormatRuntimeError("Duplicate key: %.*s",
-						 int(key.size), key.data);
+						 int(key.size()), key.data());
 	} else
 		throw std::runtime_error("Syntax error");
 }
