@@ -1,22 +1,5 @@
-/* mpdscribble (MPD Client)
- * Copyright (C) 2008-2019 The Music Player Daemon Project
- * Copyright (C) 2005-2008 Kuno Woudt <kuno@frob.nl>
- * Project homepage: http://musicpd.org
- 
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
-
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
-
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-*/
+// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright The Music Player Daemon Project
 
 #include "Log.hxx"
 #include "system/Error.hxx"
@@ -29,6 +12,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <errno.h>
+#include <time.h>
 
 #ifdef HAVE_SYSLOG
 #include <syslog.h>
@@ -149,7 +133,7 @@ log_deinit() noexcept
 void
 Log(LogLevel level, const char *msg) noexcept
 {
-	if (level > log_threshold)
+	if (level < log_threshold)
 		return;
 
 #ifdef HAVE_SYSLOG
@@ -163,7 +147,7 @@ Log(LogLevel level, const char *msg) noexcept
 void
 LogFormat(LogLevel level, const char *fmt, ...) noexcept
 {
-	if (level > log_threshold)
+	if (level < log_threshold)
 		return;
 
 #ifdef HAVE_SYSLOG
