@@ -1,22 +1,5 @@
-/* mpdscribble (MPD Client)
- * Copyright (C) 2008-2019 The Music Player Daemon Project
- * Copyright (C) 2005-2008 Kuno Woudt <kuno@frob.nl>
- * Project homepage: http://musicpd.org
- 
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
-
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
-
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-*/
+// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright The Music Player Daemon Project
 
 #include "ReadConfig.hxx"
 #include "util/Compiler.h"
@@ -27,6 +10,8 @@
 #include "IniFile.hxx"
 #include "SdDaemon.hxx"
 #include "config.h"
+#include "XdgBaseDirectory.hxx"
+#include "io/Path.hxx"
 
 #ifdef HAVE_LIBSYSTEMD
 #include <systemd/sd-daemon.h>
@@ -36,7 +21,10 @@
 
 #include <stdlib.h>
 #include <string.h>
+
+#ifndef _WIN32
 #include <sys/stat.h>
+#endif
 
 /*
   default locations for files.
@@ -53,6 +41,8 @@
 
 #define AS_HOST "https://post.audioscrobbler.com/"
 
+#ifndef _WIN32
+
 [[gnu::pure]]
 static bool
 file_exists(const char *filename) noexcept
@@ -61,33 +51,31 @@ file_exists(const char *filename) noexcept
 	return stat(filename, &st) == 0 && S_ISREG(st.st_mode);
 }
 
+#endif
+
 static std::string
 get_default_config_path(Config &config)
 {
 #ifndef _WIN32
-	const char *XDG_CONFIG_HOME = getenv("XDG_CONFIG_HOME");
-	const char *HOME = getenv("HOME");
-	std::string FILE_HOME_CONF = XDG_CONFIG_HOME ?
-		std::string(XDG_CONFIG_HOME) + "/mpdscribble/mpdscribble.conf" :
-		std::string(HOME) + "/.config/mpdscribble/mpdscribble.conf";
-	std::string LEGACY_FILE_HOME_CONF =
-			std::string(HOME) + "/.mpdscribble/mpdscribble.conf";
-	/* const char *LEGACY_FILE_HOME_CONF = "~/.mpdscribble/mpdscribble.conf"; */
-	if (file_exists(LEGACY_FILE_HOME_CONF.c_str()) &&
-			!file_exists(FILE_HOME_CONF.c_str())) {
-		FILE_HOME_CONF = std::move(LEGACY_FILE_HOME_CONF);
+	if (auto dir = GetUserConfigDirectory(PACKAGE); !dir.empty()) {
+		auto path = BuildPath(dir, "mpdscribble.conf");
+		if (file_exists(path.c_str())) {
+			config.loc = file_home;
+			return path;
+		}
 	}
-	auto file = FILE_HOME_CONF;
-	if (file_exists(file.c_str())) {
-		config.loc = file_home;
-		return file;
-	} else {
-		if (!file_exists(FILE_CONF))
-			return {};
 
-		config.loc = file_etc;
-		return FILE_CONF;
+	const char *HOME = getenv("HOME");
+	if (HOME != nullptr) {
+		auto path = BuildPath(HOME, ".mpdscribble/mpdscribble.conf");
+		if (file_exists(path.c_str())) {
+			config.loc = file_home;
+			return path;
+		}
 	}
+
+	config.loc = file_etc;
+	return FILE_CONF;
 #else
 	(void)config;
 	return "mpdscribble.conf";
@@ -112,11 +100,12 @@ get_default_log_path() noexcept
 static std::string
 GetXdgCachePath() noexcept
 {
-	const char *xdg_cache_home = getenv("XDG_CACHE_HOME");
-	if (xdg_cache_home == nullptr)
+	auto dir = GetUserCacheDirectory(PACKAGE);
+	if (dir.empty())
 		return {};
 
-	return std::string(xdg_cache_home) + "/mpdscribble/mpdscribble.cache";
+	mkdir(dir.c_str(), 0777);
+	return BuildPath(dir, "mpdscribble.cache");
 }
 
 [[gnu::pure]]
